==> enterprisemodules-ora_config-3.14.3.tar.gz: enterprisemodules-ora_config-3.14.3/lib/puppet/type/ora_service/available_instances.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:available_instances, :array_matching => :all) do
  include Puppet_X::EnterpriseModules::Oracle::ServiceProperty
  include EasyType::ArrayProperty

  desc <<-EOD
    A list of instance names to activate the service on.

    Here is an example on how to use this:

        ora_service{'my_service':
          ...
          available_instances => ['SID1', 'SID2', 'SID3'],
          ...
        }

    When an instance is specified that does not or not yet exist in the cluster, Puppet will
    ignore it.

  EOD

  column_name 'Available instances'
  data_type("Optional[Variant[String[1],Array]]")

  def insync?(is)
    if cluster?
      super(is)
    else
      Puppet.warning "#{path}: #{name} has no effect on non clustered service."
    end
  end

  to_translate_to_resource do |raw_resource|
    value = super(raw_resource)
    value.nil? ? nil : value.to_s.split(',').map(&:strip)
  end

  on_create do
    apply('create')
  end

  on_modify do
    # modify is handled in after_modify of preferred_instances
    nil
  end

  private

  def apply(type)
    if cluster?
      if unknown_instances?
        Puppet.warning "#{path}: Skipping unknown instances #{unknown_instances.join(',')}" unless @warned
        @warned = true
        nil
      else
        provider.send("#{type}_#{self.class.name}", value) if value.any?
      end
    else
      Puppet.warning "#{path}: #{name} has no effect on non clustered service."
    end
  end

  def unknown_instances?
    unknown_instances.any?
  end

  def unknown_instances
    value - cluster_instances
  end

  def known_instances
    value & cluster_instances
  end


end

==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/lib/puppet/type/ora_service/available_instances.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:available_instances, :array_matching => :all) do
  include Puppet_X::EnterpriseModules::Oracle::ServiceProperty
  include EasyType::ArrayProperty

  desc <<-DESC
    A list of instance names to activate the service on.

    Here is an example on how to use this:

        ora_service{'my_service':
          ...
          available_instances => ['SID1', 'SID2', 'SID3'],
          ...
        }

    When an instance is specified that does not or not yet exist in the cluster, Puppet will
    ignore it.

  DESC

  column_name 'Available instances'
  data_type('Optional[Variant[String[1],Array]]')

  def insync?(is)
    if cluster?
      super(is)
    else
      Puppet.warning "#{path}: #{name} has no effect on non clustered service."
    end
  end

  to_translate_to_resource do |raw_resource|
    value = super(raw_resource)
    value.nil? ? nil : value.to_s.split(',').map(&:strip)
  end

  on_create do
    apply('create')
  end

  on_modify do
    # modify is handled in after_modify of preferred_instances
    nil
  end

  private

  def apply(type)
    if cluster?
      if unknown_instances?
        Puppet.warning "#{path}: Skipping unknown instances #{unknown_instances.join(',')}" unless @warned
        @warned = true
        nil
      elsif value.any?
        provider.send("#{type}_#{self.class.name}", value)
      end
    else
      Puppet.warning "#{path}: #{name} has no effect on non clustered service."
    end
  end

  def unknown_instances?
    unknown_instances.any?
  end

  def unknown_instances
    value - cluster_instances
  end

  def known_instances
    value & cluster_instances
  end
end
